<title>web and software dev</title>
<meta name="viewport" content="width=device-width, initial-scale=1.0">
<meta charset="utf-8">
<meta name="description" content="{{ info['head']['description'] }}">
<meta name="keywords" content="{{ info['head']['keywords'] }}">
<meta name="author" content="{{ info['head']['author'] }}">
<meta name="theme-color" content="{{ info['head']['theme-color'] }}" />
<link rel="icon" href="">
<script type="text/javascript" src="js/script.js"></script>
<link rel="stylesheet" type="text/css" href="css/styles.css">