///
/// Phantom by HTML5 UP
/// html5up.net | @ajlkn
/// Free for personal and commercial use under the CCA 3.0 license (html5up.net/license)
///

/* Main */

	#main {
		@include padding(5em, 0, (-5em, 0, 3em, 0));

		@include breakpoint('<=small') {
			@include padding(3em, 0, (-3em, 0, 3em, 0));
		}
	}