OUTPUT_FOLDER = 'dist/'
info = {
    "social": {
        "facebook": "",
        "twitter": "https://twitter.com/osdotsystem",
        "instagram": "",
        "github": ""
    },
    "nav": [
        ["Main Page", "index.html", "page_1"],
        ["Page 2", "index2.html", "page_2"],
        ["Page 3", "index3.html", "page_3"],
    ]
}
