///
/// Phantom by HTML5 UP
/// html5up.net | @ajlkn
/// Free for personal and commercial use under the CCA 3.0 license (html5up.net/license)
///

/* Section/Article */

	section, article {
		&.special {
			text-align: center;
		}
	}

	header {
		p {
			margin-top: _size(element-margin) * -0.5;
		}

		@include breakpoint('<=small') {
			p {
				margin-top: 0;
			}
		}
	}