<!DOCTYPE HTML>
<!--
	Phantom by HTML5 UP
	html5up.net | @ajlkn
	Free for personal and commercial use under the CCA 3.0 license (html5up.net/license)
-->
<html>
	<head>
		{% include 'sections/head_content.html' %}
		{% block head %}
			<title>{{ info['pagename'] }} POST</title>
		{% endblock %}
	</head>
	<body class="is-preload">
		<!-- Wrapper -->
		<div id="wrapper">
			<!-- Header -->
			<header id="header">
				<div class="inner">
					<!-- Logo -->
					<a href="index.html" class="logo">
						<span class="symbol"><img src="{{ info['logo'] }}" alt="" /></span><span class="title">{{ info['pagename'] }}</span>
					</a>
					<!-- Nav -->
					<nav>
						<ul>
							<li><a href="#menu">Menu</a></li>
						</ul>
					</nav>
				</div>
			</header>
			<!-- Menu -->
			<nav id="menu">
				<h2>Menu</h2>
				<ul>
					{% for item in info['sidebar'] %}
						{% set items = info['sidebar'] %}
						{% set title = items[item]['title'] %}
						{% set page = items[item]['page'] %}
						<li><a href="{{ page }}">{{ title }}</a></li>
					{% endfor %}
				</ul>
			</nav>
			<!-- Main -->
			<div id="main">
				<div class="inner">
					<h1>LOREM IPSUM POST</h1>
					<span class="image main"><img src="https://picsum.photos/1132/326?blur=2?random=2" alt="" /></span>
					<p>Donec eget ex magna. Interdum et malesuada fames ac ante ipsum primis in faucibus. Pellentesque venenatis dolor imperdiet dolor mattis sagittis. Praesent rutrum sem diam, vitae egestas enim auctor sit amet. Pellentesque leo mauris, consectetur id ipsum sit amet, fergiat. Pellentesque in mi eu massa lacinia malesuada et a elit. Donec urna ex, lacinia in purus ac, pretium pulvinar mauris. Curabitur sapien risus, commodo eget turpis at, elementum convallis elit. Pellentesque enim turpis, hendrerit tristique.</p>
					<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Duis dapibus rutrum facilisis. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Etiam tristique libero eu nibh porttitor fermentum. Nullam venenatis erat id vehicula viverra. Nunc ultrices eros ut ultricies condimentum. Mauris risus lacus, blandit sit amet venenatis non, bibendum vitae dolor. Nunc lorem mauris, fringilla in aliquam at, euismod in lectus. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. In non lorem sit amet elit placerat maximus. Pellentesque aliquam maximus risus, vel venenatis mauris vehicula hendrerit.</p>
				</div>
			</div>
			{% include 'sections/footer.html' %}
		</div>
		{% include 'sections/bottom_scripts.html' %}
	</body>
</html>