<!-- Footer -->
<footer id="footer">
	<section>
		<form method="post" action="#">
			<div class="fields">
				<div class="field">
					<label for="name">Name</label>
					<input type="text" name="name" id="name" />
				</div>
				<div class="field">
					<label for="email">Email</label>
					<input type="text" name="email" id="email" />
				</div>
				<div class="field">
					<label for="message">Message</label>
					<textarea name="message" id="message" rows="3"></textarea>
				</div>
			</div>
			<ul class="actions">
				<li><input type="submit" value="Send Message" /></li>
			</ul>
		</form>
	</section>
	<section class="split contact">
		<section class="alt">
			<h3>Address</h3>
			<p>1234 Somewhere Road #87257<br />
			Nashville, TN 00000-0000</p>
		</section>
		<section>
			<h3>Phone</h3>
			<p><a href="#">(000) 000-0000</a></p>
		</section>
		<section>
			<h3>Email</h3>
			<p><a href="#">info@untitled.tld</a></p>
		</section>
		<section>
			<h3>Social</h3>
			<ul class="icons alt">
				<li><a href="{{ info['social']['twitter'] }}" class="icon brands alt fa-twitter"><span class="label">Twitter</span></a></li>
				<li><a href="{{ info['social']['facebook'] }}" class="icon brands alt fa-facebook-f"><span class="label">Facebook</span></a></li>
				<li><a href="{{ info['social']['instagram'] }}" class="icon brands alt fa-instagram"><span class="label">Instagram</span></a></li>
				<li><a href="{{ info['social']['github'] }}" class="icon brands alt fa-github"><span class="label">GitHub</span></a></li>
			</ul>
		</section>
	</section>
</footer>